==> koffice-2.1.0.tar.bz2: koffice-2.1.0/krita/plugins/paintops/filterop/kis_filterop.h <==
/*
 *  Copyright (c) 2002 Patrick Julien <freak@codepimps.org>
 *  Copyright (c) 2004-2008 Boudewijn Rempt <boud@valdyas.org>
 *  Copyright (c) 2004 Clarence Dang <dang@kde.org>
 *  Copyright (c) 2004 Adrian Page <adrian@pagenet.plus.com>
 *  Copyright (c) 2004 Cyrille Berger <cberger@cberger.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef KIS_FILTEROP_H_
#define KIS_FILTEROP_H_

#include "kis_brush_based_paintop.h"
#include <klocale.h>
#include <QDialog>
#include <KoColorSpace.h>

class KisFilterOpSettings;
class KisPaintInformation;
class KisPainter;

class KisFilterOp : public KisBrushBasedPaintOp
{

public:

    KisFilterOp(const KisFilterOpSettings *settings, KisPainter * painter);
    virtual ~KisFilterOp();

    void paintAt(const KisPaintInformation& info);

private:

    const KisFilterOpSettings * settings;
    KisPaintDeviceSP m_tmpDevice;
};

#endif // KIS_FILTEROP_H_

==> koffice_2.2.1.orig.tar.bz2: koffice-2.2.1/krita/plugins/paintops/filterop/kis_filterop.h <==
/*
 *  Copyright (c) 2002 Patrick Julien <freak@codepimps.org>
 *  Copyright (c) 2004-2008 Boudewijn Rempt <boud@valdyas.org>
 *  Copyright (c) 2004 Clarence Dang <dang@kde.org>
 *  Copyright (c) 2004 Adrian Page <adrian@pagenet.plus.com>
 *  Copyright (c) 2004 Cyrille Berger <cberger@cberger.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef KIS_FILTEROP_H_
#define KIS_FILTEROP_H_

#include "kis_brush_based_paintop.h"
#include <KoColorSpace.h>
#include <kis_pressure_size_option.h>

class KisFilterConfiguration;
class KisFilterOpSettings;
class KisPaintInformation;
class KisPainter;

class KisFilterOp : public KisBrushBasedPaintOp
{

public:

    KisFilterOp(const KisFilterOpSettings *settings, KisPainter * painter, KisImageWSP image);
    virtual ~KisFilterOp();

    double paintAt(const KisPaintInformation& info);

private:

    const KisFilterOpSettings * settings;
    KisPaintDeviceSP m_tmpDevice;
    KisPressureSizeOption m_sizeOption;
    KisFilterSP m_filter;
    KisFilterConfiguration* m_filterConfiguration;
    bool m_ignoreAlpha;
};

#endif // KIS_FILTEROP_H_
